<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>o/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Kadens</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Gjen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>rpm</source>
        <translation>o/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="160"/>
        <source>Supported files</source>
        <translation>Støttede filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="161"/>
        <source>CSV files</source>
        <translation>CSV-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="162"/>
        <source>CUP files</source>
        <translation>CUP-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="163"/>
        <source>FIT files</source>
        <translation>FIT-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="164"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="165"/>
        <source>GPI files</source>
        <translation>GPI-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="166"/>
        <source>GPX files</source>
        <translation>GPX-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="167"/>
        <source>IGC files</source>
        <translation>IGC-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="168"/>
        <source>ITN files</source>
        <translation>ITN-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="169"/>
        <source>JPEG images</source>
        <translation>JPEG-bilder</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="170"/>
        <source>KML files</source>
        <translation>KML-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="171"/>
        <source>LOC files</source>
        <translation>LOC-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="172"/>
        <source>NMEA files</source>
        <translation>NMEA-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="173"/>
        <source>ONmove files</source>
        <translation>ONmove-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="174"/>
        <source>OV2 files</source>
        <translation>OV2-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="175"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="176"/>
        <source>SLF files</source>
        <translation>SLF-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="177"/>
        <source>SML files</source>
        <translation>SML-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="178"/>
        <source>TCX files</source>
        <translation>TCX-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="179"/>
        <source>TwoNav files</source>
        <translation>TwoNav-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="180"/>
        <source>GPSDump files</source>
        <translation>GPSDump-filer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="181"/>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Systemstandard</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Velg mappe</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Opp</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Ned</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Min.</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Stigning</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Nedstigning</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>fot</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>ft</source>
        <translation>fot</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="36"/>
        <source>Ascent</source>
        <translation>Stigning</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Descent</source>
        <translation>Nedstigning</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Velg fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Ingen utdatafil valgt.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 er en mappe.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 er skrivebeskyttet.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="61"/>
        <location filename="../src/GUI/format.cpp" line="84"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="68"/>
        <location filename="../src/GUI/format.cpp" line="81"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="71"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="199"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="207"/>
        <location filename="../src/GUI/gui.cpp" line="951"/>
        <location filename="../src/GUI/gui.cpp" line="969"/>
        <source>Paths</source>
        <translation>Mappebaner</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="211"/>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Keyboard controls</source>
        <translation>Tastatursnarveier</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="215"/>
        <location filename="../src/GUI/gui.cpp" line="878"/>
        <source>About GPXSee</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="221"/>
        <source>Open...</source>
        <translation>Åpne…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="228"/>
        <source>Open directory...</source>
        <translation>Åpne mappe …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="233"/>
        <source>Print...</source>
        <translation>Skriv ut…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="239"/>
        <source>Export to PDF...</source>
        <translation>Eksporter til PDF…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="246"/>
        <source>Export to PNG...</source>
        <translation>Eksporter til PNG…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="260"/>
        <source>Reload</source>
        <translation>Last inn igjen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="266"/>
        <source>Statistics...</source>
        <translation>Statistikk…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="276"/>
        <source>Clear list</source>
        <translation>Tøm liste</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="288"/>
        <source>Load POI file...</source>
        <translation>Last inn interessepunkt-fil…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="292"/>
        <source>Select all files</source>
        <translation>Velg alle filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="297"/>
        <source>Unselect all files</source>
        <translation>Fravelg alle filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="302"/>
        <source>Overlap POIs</source>
        <translation>Overlapp interessepunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="307"/>
        <source>Show POI icons</source>
        <translation>Vis interessepunktikoner</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="312"/>
        <source>Show POI labels</source>
        <translation>Vis interessepunktetiketter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="318"/>
        <source>Show POIs</source>
        <translation>Vis interessepunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="330"/>
        <source>Show map</source>
        <translation>Vis kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="339"/>
        <source>Load map...</source>
        <translation>Last inn kart…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="344"/>
        <source>Load map directory...</source>
        <translation>Last inn kartmappe…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Clear tile cache</source>
        <translation>Tøm flishurtiglager</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="352"/>
        <location filename="../src/GUI/gui.cpp" line="357"/>
        <location filename="../src/GUI/gui.cpp" line="930"/>
        <source>Next map</source>
        <translation>Neste kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="362"/>
        <source>Show cursor coordinates</source>
        <translation>Vis peker-koordinater</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="370"/>
        <source>Show position</source>
        <translation>Vis posisjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="376"/>
        <source>Follow position</source>
        <translation>Følg posisjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="381"/>
        <source>Show coordinates</source>
        <translation>Vis koordinater</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="387"/>
        <source>Show motion info</source>
        <translation>Vis bevegelsesinfo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="394"/>
        <source>Show tracks</source>
        <translation>Vis spor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="399"/>
        <source>Show routes</source>
        <translation>Vis ruter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show waypoints</source>
        <translation>Vis veipunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="408"/>
        <source>Show areas</source>
        <translation>Vis områder</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="412"/>
        <source>Waypoint icons</source>
        <translation>Veipunktikoner</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="417"/>
        <source>Waypoint labels</source>
        <translation>Veipunktetiketter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="422"/>
        <source>Route waypoints</source>
        <translation>Ruteveipunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="427"/>
        <source>km/mi markers</source>
        <translation>km/mi-markører</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="435"/>
        <source>Do not show</source>
        <translation>Ikke vis</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="439"/>
        <source>Marker only</source>
        <translation>Kun markør</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="443"/>
        <source>Date/time</source>
        <translation>Dato/tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="447"/>
        <source>Coordinates</source>
        <translation>Koordinater</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="451"/>
        <source>Use styles</source>
        <translation>Bruk stiler</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="469"/>
        <source>Show local DEM tiles</source>
        <translation>Vis lokale DEM-fliser</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="472"/>
        <source>Show hillshading</source>
        <translation>Vis relieffskygge</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="480"/>
        <source>Show graphs</source>
        <translation>Vis diagrammer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <location filename="../src/GUI/gui.cpp" line="1370"/>
        <location filename="../src/GUI/gui.cpp" line="1430"/>
        <source>Distance</source>
        <translation>Distanse</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="495"/>
        <location filename="../src/GUI/gui.cpp" line="740"/>
        <location filename="../src/GUI/gui.cpp" line="1372"/>
        <location filename="../src/GUI/gui.cpp" line="1432"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="501"/>
        <source>Show grid</source>
        <translation>Vis rutenett</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="506"/>
        <source>Show slider info</source>
        <translation>Vis skyverinfo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="512"/>
        <source>Show tabs</source>
        <translation>Vis faner</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="521"/>
        <source>Show toolbars</source>
        <translation>Vis verktøylinjer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="528"/>
        <source>Total time</source>
        <translation>Total tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="533"/>
        <location filename="../src/GUI/gui.cpp" line="1373"/>
        <location filename="../src/GUI/gui.cpp" line="1434"/>
        <source>Moving time</source>
        <translation>Tid i bevegelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="545"/>
        <source>Imperial</source>
        <translation>Britisk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="551"/>
        <source>Nautical</source>
        <translation>Nautisk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Decimal degrees (DD)</source>
        <translation>Desimalgrader (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="565"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Grader og desimalminutter (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="572"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Grader, minutter, sekunder (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="579"/>
        <source>Fullscreen mode</source>
        <translation>Fullskjermmodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="586"/>
        <source>Options...</source>
        <translation>Alternativer…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="593"/>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="603"/>
        <source>Last</source>
        <translation>Siste</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="608"/>
        <source>First</source>
        <translation>Første</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="643"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="646"/>
        <source>Open recent</source>
        <translation>Åpne nylige</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="671"/>
        <source>&amp;Map</source>
        <translation>&amp;Kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="681"/>
        <source>&amp;Graph</source>
        <translation>&amp;Graf</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="712"/>
        <source>&amp;POI</source>
        <translation>I&amp;nteressepunkt</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="732"/>
        <source>Position</source>
        <translation>Posisjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <location filename="../src/GUI/gui.cpp" line="976"/>
        <source>CRS directory:</source>
        <translation>CRS-mappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <source>Symbols directory:</source>
        <translation>Symbolmappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1030"/>
        <source>Open directory</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1101"/>
        <location filename="../src/GUI/gui.cpp" line="1778"/>
        <location filename="../src/GUI/gui.cpp" line="1878"/>
        <source>Don&apos;t show again</source>
        <translation>Ikke vis igjen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>Tøm «%1»-flishurtiglager?</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="1964"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>Laste ned %n DEM-flis?</numerusform>
            <numerusform>Laste ned %n DEM-fliser?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="693"/>
        <source>&amp;Data</source>
        <translation>&amp;Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Download data DEM</source>
        <translation>Last ned data-DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="464"/>
        <source>Download map DEM</source>
        <translation>Last ned kart-DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="698"/>
        <source>Position info</source>
        <translation>Posisjonsinfo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="724"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="739"/>
        <source>&amp;Settings</source>
        <translation>&amp;Innstillinger</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="744"/>
        <source>Units</source>
        <translation>Enheter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="749"/>
        <source>Coordinates format</source>
        <translation>Koordinatformat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="762"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="789"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="799"/>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="807"/>
        <source>Navigation</source>
        <translation>Navigasjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="880"/>
        <location filename="../src/GUI/gui.cpp" line="888"/>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="883"/>
        <location filename="../src/GUI/gui.cpp" line="892"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee er distribuert i henhold til vilkårene i GNU general public lisens, versjon 3. For mer info om GPXSee, besøk prosjekthjemmesiden på %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="915"/>
        <source>Next file</source>
        <translation>Neste fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>Previous file</source>
        <translation>Forrige fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="918"/>
        <source>First file</source>
        <translation>Første fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="920"/>
        <source>Last file</source>
        <translation>Siste fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="921"/>
        <source>Append file</source>
        <translation>Legg til fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="922"/>
        <source>Next/Previous</source>
        <translation>Neste/forrige</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="924"/>
        <source>Toggle graph type</source>
        <translation>Veksle diagramtype</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="926"/>
        <source>Toggle time type</source>
        <translation>Veksle tidstype</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="928"/>
        <source>Toggle position info</source>
        <translation>Veksle posisjonsinfo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="932"/>
        <source>Previous map</source>
        <translation>Forrige kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="933"/>
        <source>Zoom in</source>
        <translation>Zoom inn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <source>Zoom out</source>
        <translation>Zoom ut</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="937"/>
        <source>Digital zoom</source>
        <translation>Digital zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="938"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Copy coordinates</source>
        <translation>Kopier koordinater</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Left Click</source>
        <translation>Venstreklikk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <source>DEM directory:</source>
        <translation>DEM-mappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <source>Styles directory:</source>
        <translation>Stilmappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="966"/>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <source>Tile cache directory:</source>
        <translation>Flishurtiglagringsmappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1912"/>
        <source>Select map directory</source>
        <translation>Velg kartmappe</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <location filename="../src/GUI/gui.cpp" line="972"/>
        <source>Map directory:</source>
        <translation>Kartmappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <location filename="../src/GUI/gui.cpp" line="974"/>
        <source>POI directory:</source>
        <translation>Interessepunktmappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>Open file</source>
        <translation>Åpne fil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1093"/>
        <source>Error loading data file:</source>
        <translation>Feil ved innlasting av datafil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1096"/>
        <location filename="../src/GUI/gui.cpp" line="1208"/>
        <source>Line: %1</source>
        <translation>Linje: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1175"/>
        <location filename="../src/GUI/gui.cpp" line="1178"/>
        <source>Open POI file</source>
        <translation>Åpne interessepunktfil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1205"/>
        <source>Error loading POI file:</source>
        <translation>Feil ved innlasting av interessepunktfil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1352"/>
        <location filename="../src/GUI/gui.cpp" line="1410"/>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1354"/>
        <location filename="../src/GUI/gui.cpp" line="1412"/>
        <source>Routes</source>
        <translation>Ruter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1356"/>
        <location filename="../src/GUI/gui.cpp" line="1414"/>
        <source>Waypoints</source>
        <translation>Veipunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1358"/>
        <location filename="../src/GUI/gui.cpp" line="1416"/>
        <source>Areas</source>
        <translation>Områder</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1362"/>
        <location filename="../src/GUI/gui.cpp" line="1364"/>
        <location filename="../src/GUI/gui.cpp" line="1421"/>
        <location filename="../src/GUI/gui.cpp" line="1423"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1385"/>
        <location filename="../src/GUI/gui.cpp" line="1388"/>
        <location filename="../src/GUI/gui.cpp" line="1389"/>
        <source>Statistics</source>
        <translation>Statistikk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1406"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1717"/>
        <location filename="../src/GUI/gui.cpp" line="1720"/>
        <source>Open map file</source>
        <translation>Åpne kartfil</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1772"/>
        <location filename="../src/GUI/gui.cpp" line="1829"/>
        <location filename="../src/GUI/gui.cpp" line="1848"/>
        <location filename="../src/GUI/gui.cpp" line="1872"/>
        <source>Error loading map:</source>
        <translation>Feil ved innlasting av kart:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1961"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1977"/>
        <source>Could not download all required DEM files.</source>
        <translation>Kunne ikke laste ned alle påkrevde DEM-filer.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1997"/>
        <source>No local DEM tiles found.</source>
        <translation>Fant ingen lokale DEM-fliser.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2011"/>
        <source>No files loaded</source>
        <translation>Ingen filer lastet</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2015"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n fil</numerusform>
            <numerusform>%n filer</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Utveksling</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Topp</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Mest brukt</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="35"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="36"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Most used</source>
        <translation>Mest brukt</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="74"/>
        <source>Data not available</source>
        <translation>Data ikke tilgjengelig</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="94"/>
        <location filename="../src/GUI/graphview.cpp" line="199"/>
        <source>Distance</source>
        <translation>Distanse</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>ft</source>
        <translation>fot</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="147"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="150"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="156"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="159"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="162"/>
        <source>h</source>
        <translation>t</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="201"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>slag/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Puls</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Gjen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="18"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <source>bpm</source>
        <translation>slag/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="79"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="81"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Støttede filer</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB-sjøkart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>Elektroniske sjøkart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps-SQLite-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy-kart/atlas</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF-bilder</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav-kart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>World-file georefererte bilder</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Nettbaserte kartkilder</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/t</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="83"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>Ikke-HiDPI-kart lastes som HiDPI-kart. Kartet er skarpt, men kartobjekter er små/vanskelige å lese.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>Ikke-HiDPI-kart lastes som de er. Kartobjekter har forventet størrelse, men kartet er uskarpt.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="129"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI-visningsmodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="179"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="202"/>
        <source>Base color:</source>
        <translation>Grunnfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="203"/>
        <source>Palette shift:</source>
        <translation>Palettforskyvning:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="169"/>
        <source>Track width:</source>
        <translation>Sporbredde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="95"/>
        <source>Input</source>
        <translation>Inndata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="97"/>
        <source>Output</source>
        <translation>Utdata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="170"/>
        <source>Track style:</source>
        <translation>Sporstil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="186"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="191"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="192"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="197"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="172"/>
        <source>Route width:</source>
        <translation>Rutebredde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="173"/>
        <source>Route style:</source>
        <translation>Rutestil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="193"/>
        <source>Routes</source>
        <translation>Ruter</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="175"/>
        <source>Area border width:</source>
        <translation>Kantbredde for område:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="176"/>
        <source>Area border style:</source>
        <translation>Kantstil for område:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Area fill opacity:</source>
        <translation>Ugjennomsiktighet for område:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <source>Areas</source>
        <translation>Områder</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="163"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="267"/>
        <source>Use anti-aliasing</source>
        <translation>Bruk kantutjevning</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <source>Waypoint color:</source>
        <translation>Veipunktfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="236"/>
        <source>Waypoint size:</source>
        <translation>Veipunktstørrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="248"/>
        <source>Color:</source>
        <translation>Farge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="249"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="245"/>
        <source>Waypoints</source>
        <translation>Veipunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="238"/>
        <source>POI color:</source>
        <translation>Interessepunktfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="239"/>
        <source>POI size:</source>
        <translation>Interessepunktstørrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="250"/>
        <source>POIs</source>
        <translation>Interessepunkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="279"/>
        <source>Line width:</source>
        <translation>Linjebredde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="274"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="280"/>
        <source>Slider color:</source>
        <translation>Skyverfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="305"/>
        <source>Background color:</source>
        <translation>Bakgrunnsfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="318"/>
        <source>Paths</source>
        <translation>Stier</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="319"/>
        <source>Points</source>
        <translation>Punkter</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="320"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="757"/>
        <source>Graphs</source>
        <translation>Diagrammer</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="321"/>
        <source>Map</source>
        <translation>Kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <source>Moving average window size</source>
        <translation>Vindusstørrelse for glidende gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="353"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="480"/>
        <source>Elevation:</source>
        <translation>Høyde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="479"/>
        <source>Speed:</source>
        <translation>Hastighet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="355"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <source>Heart rate:</source>
        <translation>Puls:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="356"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="366"/>
        <source>Cadence:</source>
        <translation>Kadens:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="357"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="367"/>
        <source>Power:</source>
        <translation>Kraft:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="352"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="370"/>
        <source>Smoothing</source>
        <translation>Utjevning</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="346"/>
        <source>Eliminate GPS outliers</source>
        <translation>Eliminer GPS-ekstremverdier</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="380"/>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="394"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="397"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="400"/>
        <source>km/h</source>
        <translation>km/t</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="404"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="784"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="527"/>
        <source>Minimal speed:</source>
        <translation>Minimumshastighet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="528"/>
        <source>Minimal duration:</source>
        <translation>Minimumsvarighet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>Computed from distance/time</source>
        <translation>Beregnet fra distanse/tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="412"/>
        <source>Recorded by device</source>
        <translation>Tatt opp av enhet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="417"/>
        <source>Show secondary speed</source>
        <translation>Vis sekundær hastighet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="420"/>
        <source>GPS data</source>
        <translation>GPS-data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="421"/>
        <source>DEM data</source>
        <translation>DEM-data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Show secondary elevation</source>
        <translation>Vis sekundær høyde</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="429"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="450"/>
        <source>Use segments</source>
        <translation>Bruk segmenter</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="481"/>
        <source>Time zone:</source>
        <translation>Tidssone:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="500"/>
        <source>Elevation</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="506"/>
        <source>Time zone</source>
        <translation>Tidssone</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="540"/>
        <source>Filtering</source>
        <translation>Filtrering</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Sources</source>
        <translation>Kilder</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="541"/>
        <source>Pause detection</source>
        <translation>Pausedetektering</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="563"/>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="70"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>Velg riktig koordinatreferansesystem (CRS) for kart uten en CRS-definisjon (JNX, KMZ og World-file kart).</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="73"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Velg ønsket projeksjon for vektorkart (IMG, Mapsforge og ENC-kart). Projeksjonen må være gyldig for hele kartområdet.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="104"/>
        <source>Input:</source>
        <translation>Inndata:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="107"/>
        <source>Output:</source>
        <translation>Utdata:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="128"/>
        <source>Projection</source>
        <translation>Kartprojeksjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="139"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="146"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="152"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="220"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="227"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="265"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="628"/>
        <source>px</source>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="301"/>
        <source>Info background</source>
        <translation>Info-bakgrunn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="307"/>
        <source>Crosshair color:</source>
        <translation>Trådkorsfarge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="308"/>
        <source>Info color:</source>
        <translation>Info-farge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="381"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="431"/>
        <source>Custom</source>
        <translation>Egendefinert</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="553"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="556"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="559"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="569"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="877"/>
        <source>POI</source>
        <translation>Interessepunkt</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="586"/>
        <source>Use HTTP authentication</source>
        <translation>Bruk HTTP-autentisering</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="592"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>Bruk $lat og $lon for NYY/SYY og EXXX/WXXX i nettadressen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="610"/>
        <source>URL:</source>
        <translation>Nettadresse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="198"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="306"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="644"/>
        <source>Opacity:</source>
        <translation>Ugjennomsiktighet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="646"/>
        <source>Blur radius:</source>
        <translation>Sløreradius:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="648"/>
        <source>Azimuth:</source>
        <translation>Asimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="649"/>
        <source>Altitude:</source>
        <translation>Høyde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="650"/>
        <source>Z Factor:</source>
        <translation>Z-faktor:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="689"/>
        <source>Source</source>
        <translation>Kilde</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Hillshading</source>
        <translation>Relieffskygge</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="676"/>
        <source>Plugin:</source>
        <translation>Programtillegg:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="77"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="697"/>
        <source>High-Resolution</source>
        <translation>Høyoppløsning</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="645"/>
        <source>Lightening:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="702"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>Det utskrevne området er omtrent det samme som visningsområdet. Kartets zoomnivå endres ikke.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>Zoomnivået vil endres slik at hele innholdet (spor/veipunkter) passer med utskrevet område og kartoppløsningen er så lik utskriftsoppløsningen som mulig.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="720"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="722"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="724"/>
        <source>Distance</source>
        <translation>Distanse</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="726"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="728"/>
        <source>Moving time</source>
        <translation>Tid i bevegelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="730"/>
        <source>Item count (&gt;1)</source>
        <translation>Elementantall (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="745"/>
        <source>Separate graph page</source>
        <translation>Separat diagramside</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="755"/>
        <source>Print mode</source>
        <translation>Utskriftsmodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="756"/>
        <source>Header</source>
        <translation>Topptekst</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Use OpenGL</source>
        <translation>Bruk OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="766"/>
        <source>Enable HTTP/2</source>
        <translation>Aktiver HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="772"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="778"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="790"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <source>Image cache size:</source>
        <translation>Bildehurtiglagerstørrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="792"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="800"/>
        <source>Connection timeout:</source>
        <translation>Tilkoblingstidsavbrudd:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="430"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="835"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <source>DEM cache size:</source>
        <translation>DEM-hurtiglagerstørrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="819"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Velg forvalgte mappebaner for filåpningsdialoger. La feltet stå tomt for systemstandard.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="823"/>
        <source>Data:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="824"/>
        <source>Maps:</source>
        <translation>Kart:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="825"/>
        <source>POI:</source>
        <translation>Interessepunkt:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="836"/>
        <source>Initial paths</source>
        <translation>Forvalgte mappebaner</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="872"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="874"/>
        <source>Maps</source>
        <translation>Kart</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="876"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="882"/>
        <source>Position</source>
        <translation>Posisjon</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>Print &amp; Export</source>
        <translation>Utskrift og eksport</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="919"/>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF-filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Stående</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Liggende</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>tommer</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Sideoppsett</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Sidestørrelse:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Oppløsning:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Sideretning:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Marger:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Utdatafil</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Eksporter til PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG-filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Bruk kantutjevning</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Bildeoppsett</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Bildebredde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Bildehøyde:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Marger:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Utdatafil</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Eksporter til PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="17"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="19"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Kraft</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Gjen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Distanse</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Lenker</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Gjen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="133"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="136"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="139"/>
        <source>km/h</source>
        <translation>km/t</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="23"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>km/h</source>
        <translation>km/t</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="27"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="31"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Gjen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min.</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Maks.</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="111"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="115"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="24"/>
        <source>Average</source>
        <translation>Gjennomsnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Distanse</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Total tid</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Tid i bevegelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="27"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="38"/>
        <source>Links</source>
        <translation>Lenker</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="25"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Coordinates</source>
        <translation>Koordinater</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="33"/>
        <source>Elevation</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="36"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="40"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="44"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="52"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="65"/>
        <source>Links</source>
        <translation>Lenker</translation>
    </message>
</context>
</TS>
